import { FASTElement } from "@microsoft/fast-element";
import { ConstructibleResizeObserver } from "./resize-observer";
declare global {
    interface WindowWithResizeObserver extends Window {
        ResizeObserver: ConstructibleResizeObserver;
    }
}
export declare type AxisPositioningMode = "uncontrolled" | "locktodefault" | "dynamic";
export declare type HorizontalPosition = "start" | "end" | "left" | "right" | "unset";
export declare type VerticalPosition = "top" | "bottom" | "unset";
export interface Dimension {
    height: number;
    width: number;
}
declare enum AnchoredRegionHorizontalPositionLabel {
    left = "left",
    insetLeft = "insetLeft",
    insetRight = "insetRight",
    right = "right",
    undefined = "undefined"
}
declare enum AnchoredRegionVerticalPositionLabel {
    top = "top",
    insetTop = "insetTop",
    insetBottom = "insetBottom",
    bottom = "bottom",
    undefined = "undefined"
}
export declare class AnchoredRegion extends FASTElement {
    private static DirectionAttributeName;
    anchor: string;
    private anchorChanged;
    viewport: string;
    private viewportChanged;
    horizontalPositioningMode: AxisPositioningMode;
    private horizontalPositioningModeChanged;
    horizontalDefaultPosition: HorizontalPosition;
    private horizontalDefaultPositionChanged;
    horizontalInset: boolean;
    private horizontalInsetChanged;
    horizontalThreshold: string;
    private horizontalThresholdChanged;
    horizontalScaling: boolean;
    private horizontalScalingChanged;
    verticalPositioningMode: AxisPositioningMode;
    private verticalPositioningModeChanged;
    verticalDefaultPosition: VerticalPosition;
    private verticalDefaultPositionChanged;
    verticalInset: boolean;
    private verticalInsetChanged;
    verticalThreshold: string;
    private verticalThresholdChanged;
    verticalScaling: boolean;
    private verticalScalingChanged;
    regionStyle: string;
    /**
     * indicates that an initial positioning pass on layout has completed
     */
    initialLayoutComplete: boolean;
    anchorElement: HTMLElement | null;
    private anchorElementChanged;
    viewportElement: HTMLElement | null;
    private viewportElementChanged;
    /**
     * the positions currently being applied to layout
     */
    verticalPosition: AnchoredRegionVerticalPositionLabel;
    horizontalPosition: AnchoredRegionHorizontalPositionLabel;
    /**
     * values to be applied to the component's transform origin attribute on render
     */
    private transformOrigin;
    /**
     * values to be applied to the component's positioning attributes on render
     */
    private regionTop;
    private regionRight;
    private regionBottom;
    private regionLeft;
    /**
     * the span in pixels of the selected position on each axis
     */
    private regionWidth;
    private regionHeight;
    private xTransformOrigin;
    private yTransformOrigin;
    private collisionDetector;
    private resizeDetector;
    private viewportRect;
    private positionerDimension;
    private anchorTop;
    private anchorRight;
    private anchorBottom;
    private anchorLeft;
    private anchorHeight;
    private anchorWidth;
    private viewportScrollTop;
    private viewportScrollLeft;
    /**
     * base offsets between the positioner's base position and the anchor's
     */
    private baseHorizontalOffset;
    private baseVerticalOffset;
    /**
     * reference to the actual anchored container
     */
    region: HTMLDivElement;
    private openRequestAnimationFrame;
    private currentDirection;
    constructor();
    connectedCallback(): void;
    disconnectedCallback(): void;
    adoptedCallback(): void;
    /**
     * event thrown when the region's position changes
     */
    private updateLayoutForAttributeChange;
    /**
     * resets the component
     */
    private reset;
    /**
     * sets the starting configuration for component internal values
     */
    private setInitialState;
    /**
     * connects observers and event handlers
     */
    private connectObservers;
    /**
     * disconnect observers and event handlers
     */
    private disconnectObservers;
    private disconnectViewport;
    /**
     * Gets the viewport element by id, or defaults to component parent
     */
    getViewport: () => HTMLElement | null;
    /**
     *  Gets the anchor element by id
     */
    getAnchor: () => HTMLElement | null;
    /**
     *  Handle collisions
     */
    private handleCollision;
    /**
     *  Update data based on anchor collisions
     */
    private handleAnchorCollision;
    /**
     *  Update data based on positioner collisions
     */
    private handlePositionerCollision;
    /**
     *  Handle resize events
     */
    private handleResize;
    /**
     *  Handle region resize events
     */
    private handleRegionResize;
    /**
     *  Handle anchor resize events
     */
    private handleAnchorResize;
    /**
     *  Handle scroll events
     */
    private handleScroll;
    /**
     * Request's an animation frame if there are currently no open animation frame requests
     */
    private requestLayoutUpdate;
    /**
     *  Recalculate layout related state values
     */
    private updateLayout;
    /**
     *  Updates the style string applied to the region element as well as the css classes attached
     *  to the root element
     */
    private updateRegionStyle;
    /**
     * Get horizontal positioning state based on desired position
     */
    private setHorizontalPosition;
    /**
     * Get vertical positioning state based on desired position
     */
    private setVerticalPosition;
    /**
     *  Update the offset values
     */
    private updatePositionerOffset;
    /**
     * Check for scroll changes in viewport and adjust position data
     */
    private updateForScrolling;
    /**
     *  Get available Horizontal positions based on positioning mode
     */
    private getHorizontalPositioningOptions;
    /**
     * Get available Vertical positions based on positioning mode
     */
    private getVerticalPositioningOptions;
    /**
     *  Get the width available for a particular horizontal position
     */
    private getAvailableWidth;
    /**
     *  Get the height available for a particular vertical position
     */
    private getAvailableHeight;
    /**
     * Get region dimensions
     */
    private getNextRegionDimension;
    /**
     *  gets the current direction
     */
    private getDirection;
}
export {};
